@@ -209,14 +209,14 @@ func (s *BaseSuite) traefikCmd(args ...string) (*exec.Cmd, func(*check.C)) {
 	cmd, out := s.cmdTraefik(args...)
 	return cmd, func(c *check.C) {
 		if c.Failed() || *showLog {
-			s.displayLogK3S(c)
+			s.displayLogK3S()
 			s.displayLogCompose(c)
 			s.displayTraefikLog(c, out)
 		}
 	}
 }
 
-func (s *BaseSuite) displayLogK3S(c *check.C) {
+func (s *BaseSuite) displayLogK3S() {
 	filePath := "./fixtures/k8s/config.skip/k3s.log"
 	if _, err := os.Stat(filePath); err == nil {
 		content, errR := os.ReadFile(filePath)
